==> eiffelstudio-18.07.10.1981.tar: F_code/C4/et176.c <==
/*
 * Code for class ET_ADAPTED_UNIVERSE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "et176.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ET_ADAPTED_UNIVERSE}.make */
void F236_2168 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_BOOLEAN tb1;
	RTCDT;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLIU(3);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + O1785[dtype-235]) = (EIF_REFERENCE) arg2;
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R1791[dtype-235])(Current);
	*(EIF_BOOLEAN *)(Current + O1780[dtype-235]) = (EIF_BOOLEAN) tb1;
	RTLE;
}

/* {ET_ADAPTED_UNIVERSE}.name */
EIF_REFERENCE F236_2170 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {ET_ADAPTED_UNIVERSE}.lower_name */
EIF_REFERENCE F236_2171 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_8 loc3 = (EIF_CHARACTER_8) 0;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = *(EIF_REFERENCE *)(Current);
	loc2 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		loc3 = *(EIF_CHARACTER_8 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R4638[Dtype(Result)-644])(RTCW(Result), loc1));
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc3 >= (EIF_CHARACTER_8) 'A') && (EIF_BOOLEAN) (loc3 <= (EIF_CHARACTER_8) 'Z'))) {
			Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R6683[Dtype(Result)-983])(RTCW(Result));
			loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L));
		} else {
			loc1++;
		}
	}
	RTLE;
	return Result;
}

/* {ET_ADAPTED_UNIVERSE}.classname_prefix */
EIF_REFERENCE F236_2172 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {ET_ADAPTED_UNIVERSE}.class_renamings */
EIF_REFERENCE F236_2173 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {ET_ADAPTED_UNIVERSE}.universe */
EIF_REFERENCE F236_2174 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + O1785[Dtype(Current) - 235]);
}


/* {ET_ADAPTED_UNIVERSE}.export_classes */
void F236_2179 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	RTCFDT;
	RTCDT;
	RTLD;
	
	RTLI(11);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,loc2);
	RTLR(3,tr1);
	RTLR(4,loc4);
	RTLR(5,loc5);
	RTLR(6,loc6);
	RTLR(7,tr2);
	RTLR(8,loc7);
	RTLR(9,loc3);
	RTLR(10,arg1);
	RTLIU(11);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + O1785[dtype-235]);
	loc1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_4_);
	loc1 = F1232_11147(RTCW(loc1));
	F1075_10149(RTCW(loc1));
	for (;;) {
		tb1 = F1095_10177(RTCW(loc1));
		if (tb1) break;
		loc2 = F1069_10131(RTCW(loc1));
		tb2 = F1238_11183(RTCW(loc2));
		if (tb2) {
		} else {
			tr1 = F1238_11159(RTCW(loc2));
			tr1 = F1625_15965(RTCW(tr1));
			if ((EIF_BOOLEAN)(tr1 == *(EIF_REFERENCE *)(Current + O1785[dtype-235]))) {
				loc4 = F1111_10198(RTCW(loc1));
				loc5 = F1607_14871(RTCW(loc4));
				tb2 = '\0';
				tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
				loc6 = tr1;
				if (EIF_TEST(loc6)) {
					tb3 = F1222_11083(loc6, loc5);
					tb2 = tb3;
				}
				if (tb2) {
					tr1 = RTLNS(eif_new_type(1606, 0x00).id, 1606, _OBJSIZ_2_1_0_4_0_0_0_0_);
					tr2 = F1222_11076(loc6, loc5);
					F1607_14867(RTCW(tr1), tr2);
					loc4 = (EIF_REFERENCE) tr1;
				} else {
					tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
					loc7 = tr1;
					if (EIF_TEST(loc7)) {
						tr1 = RTLNS(eif_new_type(1606, 0x00).id, 1606, _OBJSIZ_2_1_0_4_0_0_0_0_);
						tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R6701[Dtype(loc7)-987])(loc7, loc5);
						F1607_14867(RTCW(tr1), tr2);
						loc4 = (EIF_REFERENCE) tr1;
					}
				}
				loc3 = F1251_11387(RTCW(arg1), loc4);
				tb2 = F1238_11193(RTCW(loc3), loc2);
				if ((EIF_BOOLEAN) !tb2) {
					F1238_11218(RTCW(loc3), loc2);
				}
			}
		}
		F1075_10150(RTCW(loc1));
	}
	RTLE;
}

/* {ET_ADAPTED_UNIVERSE}.default_read_only_value */
static EIF_BOOLEAN F236_2180_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	

	
	RTEV;
	RTOSP (2180);
#define Result RTOSR(2180)
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTOSE (2180);
	RTEE;
	return Result;
#undef Result
}

EIF_BOOLEAN F236_2180 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(2180,F236_2180_body,(Current));
}

void EIF_Minit176 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/et176.c <==
/*
 * Code for class ET_ADAPTED_GROUP
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "et176.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ET_ADAPTED_GROUP}.lower_name */
EIF_REFERENCE F238_2217 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_8 loc3 = (EIF_CHARACTER_8) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R1819[Dtype(Current)-238])(Current);
	loc2 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		loc3 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R4709[Dtype(RTCW(Result))-649])(Result, loc1));
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc3 >= (EIF_CHARACTER_8) 'A') && (EIF_BOOLEAN) (loc3 <= (EIF_CHARACTER_8) 'Z'))) {
			tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R6782[Dtype(RTCW(Result))-989])(Result);
			Result = (EIF_REFERENCE) tr1;
			loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L));
		} else {
			loc1++;
		}
	}
	RTLE;
	return Result;
}

void EIF_Minit176 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
